#ifndef __INTEGRATEFULLORBIT_H__
#define __INTEGRATEFULLORBIT_H__
#ifdef __cplusplus
extern "C" {
#endif
#include <galpy_potentials.h>
void parse_leapFuncArgs_Full(int, struct potentialArg *,int **,double **);
#ifdef __cplusplus
}
#endif
#endif /* integrateFullOrbit.h */
